@@ -1,6 +1,3 @@
-from pathlib import Path
-print('Running' if __name__ == '__main__' else 'Importing', Path(__file__).resolve())
-
 import sys
 import os
 from pycocotools import mask
